@@ -37,7 +37,7 @@ module Parser
 
     private
 
-    LEGACY_MODES = %i[lambda procarg0 encoding index arg_inside_procarg0 forward_arg].freeze
+    LEGACY_MODES = %i[lambda procarg0 encoding index arg_inside_procarg0 forward_arg kwargs match_pattern].freeze
 
     def runner_name
       raise NotImplementedError, "implement #{self.class}##{__callee__}"
@@ -113,9 +113,19 @@ module Parser
         @parser_class = Parser::Ruby27
       end
 
-      opts.on '--28', 'Parse as Ruby 2.8 would' do
-        require 'parser/ruby28'
-        @parser_class = Parser::Ruby28
+      opts.on '--30', 'Parse as Ruby 3.0 would' do
+        require 'parser/ruby30'
+        @parser_class = Parser::Ruby30
+      end
+
+      opts.on '--31', 'Parse as Ruby 3.1 would' do
+        require 'parser/ruby31'
+        @parser_class = Parser::Ruby31
+      end
+
+      opts.on '--32', 'Parse as Ruby 3.2 would' do
+        require 'parser/ruby32'
+        @parser_class = Parser::Ruby32
       end
 
       opts.on '--mac', 'Parse as MacRuby 0.12 would' do
@@ -156,6 +166,7 @@ module Parser
       @option_parser.parse!(options)
 
       # Slop has just removed recognized options from `options`.
+      @fragments << $stdin.read if options.delete('-')
       options.each do |file_or_dir|
         if File.directory?(file_or_dir)
           Find.find(file_or_dir) do |path|
