@@ -26,6 +26,8 @@ class TestCurrent < Minitest::Test
       assert_equal Parser::Ruby30, Parser::CurrentRuby
     when /^3\.1\.\d+/
       assert_equal Parser::Ruby31, Parser::CurrentRuby
+    when /^3\.2\.\d+/
+      assert_equal Parser::Ruby32, Parser::CurrentRuby
     else
       flunk "Update test_current for #{RUBY_VERSION}"
     end
